@@ -3,8 +3,10 @@
 ##' @param weights importance weights (unnormalized)
 ##' @param ... unused
 ##' @noRd
-##' @srrstats {G2.13} checks for missing data as part of initial pre-processing prior to passing data to analytic algorithms
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.13} checks for missing data as part of initial
+##'   pre-processing prior to passing data to analytic algorithms
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 mv_kl_div <- function(weights, ...) {
 
   checkmate::assert_numeric(weights, any.missing = FALSE)
@@ -20,7 +22,8 @@ mv_kl_div <- function(weights, ...) {
 ##' @param weights2 weights for second distribution
 ##' @param subsample_size size of subsamples
 ##' @param ... unused
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 mv_wasserstein_dist <- function(draws1,
                                 draws2,
@@ -32,8 +35,14 @@ mv_wasserstein_dist <- function(draws1,
 
   checkmate::assert_class(draws1, "draws")
   checkmate::assert_class(draws2, "draws")
-  checkmate::assert_numeric(weights1, len = posterior::ndraws(draws1), null.ok = TRUE, any.missing = FALSE)
-  checkmate::assert_numeric(weights2, len = posterior::ndraws(draws2), null.ok = TRUE, any.missing = FALSE)
+  checkmate::assert_numeric(weights1,
+                            len = posterior::ndraws(draws1),
+                            null.ok = TRUE,
+                            any.missing = FALSE)
+  checkmate::assert_numeric(weights2,
+                            len = posterior::ndraws(draws2),
+                            null.ok = TRUE,
+                            any.missing = FALSE)
   checkmate::assert_vector(weights1, null.ok = TRUE)
   checkmate::assert_vector(weights2, null.ok = TRUE)
   checkmate::assert_number(subsample_size, lower = 0)
@@ -81,7 +90,8 @@ mv_wasserstein_dist <- function(draws1,
 ##' @template draws_and_weights_arg
 ##' @param ... unused
 ##' @return numeric
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 js_div <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
   
@@ -93,8 +103,10 @@ js_div <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
   checkmate::assert_numeric(y, min.len = 1, any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(y, strict = TRUE)
 
-  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
-  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x_weights, len = length(x),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y_weights, len = length(y),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
   
   y_density <- stats::density(
     x = y,
@@ -147,7 +159,8 @@ js_dist <- function(x, y, x_weights, y_weights, ...) {
 ##' @template draws_and_weights_arg
 ##' @param ... unused
 ##' @return numeric
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 hellinger_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
   
@@ -159,8 +172,10 @@ hellinger_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
   checkmate::assert_numeric(y, min.len = 1, any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(y, strict = TRUE)
 
-  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
-  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE,
+                            any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE,
+                            any.missing = FALSE, finite = TRUE)
 
   
   y_density <- stats::density(
@@ -193,20 +208,25 @@ hellinger_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
 ##' @param ... unused
 ##' @return numeric value of approximate KL(p_x||p_y) based on
 ##'   estimated densitites
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 kl_div <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
 
   require_package("philentropy")
   
-  checkmate::assert_numeric(x, min.len = 1, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x, min.len = 1,
+                            any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(x, strict = TRUE)
   
-  checkmate::assert_numeric(y, min.len = 1, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y, min.len = 1,
+                            any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(y, strict = TRUE)
 
-  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
-  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x_weights, len = length(x),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y_weights, len = length(y),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
   
   y_density <- stats::density(
     x = y,
@@ -260,7 +280,8 @@ kl_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
 ##' @template draws_and_weights_arg
 ##' @param ... ununsed
 ##' @return numeric value of Kolmogorov Smirnov distance
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 ks_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
 
@@ -270,8 +291,10 @@ ks_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
   checkmate::assert_numeric(y, min.len = 1, any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(y, strict = TRUE)
 
-  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
-  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x_weights, len = length(x),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y_weights, len = length(y),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
   
   if (is.null(x_weights)) {
     x_weights <- rep(1, length(x))
@@ -293,7 +316,8 @@ ks_dist <- function(x, y, x_weights = NULL, y_weights = NULL, ...) {
 ##' @param p degree
 ##' @param ... unused
 ##' @return numeric value of Wassterstein distance
-##' @srrstats {G2.2} Input is checked that it is numeric vector and excludes matrix
+##' @srrstats {G2.2} Input is checked that it is numeric vector and
+##'   excludes matrix
 ##' @noRd
 ws_dist <- function(x, y, x_weights = NULL, y_weights = NULL, p = 1, ...) {
 
@@ -305,8 +329,10 @@ ws_dist <- function(x, y, x_weights = NULL, y_weights = NULL, p = 1, ...) {
   checkmate::assert_numeric(y, min.len = 1, any.missing = FALSE, finite = TRUE)
   checkmate::assert_vector(y, strict = TRUE)
 
-  checkmate::assert_numeric(x_weights, len = length(x), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
-  checkmate::assert_numeric(y_weights, len = length(y), null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(x_weights, len = length(x),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
+  checkmate::assert_numeric(y_weights, len = length(y),
+                            null.ok = TRUE, any.missing = FALSE, finite = TRUE)
 
   checkmate::assert_number(p, lower = 0)
   
