@@ -7,7 +7,8 @@ test_that("whiten draws returns expected structure", {
   expect_s3_class(w_drw, "whitened_draws")
   expect_s3_class(w_drw, "draws")
 
-  expect_equal(names(attributes(w_drw)), c("names", "row.names", "class", "loadings"))
+  expect_equal(names(attributes(w_drw)),
+               c("names", "row.names", "class", "loadings"))
 
   expect_true(is.matrix(attr(w_drw, "loadings")))
 }
